package com.rjconsultores.ventaboletos.service;

import com.rjconsultores.ventaboletos.entidad.VigenciaTarifa;


public interface TarifaOficialService {

	/**
	 * Gera as tarifas de acordo o clculo do coeficiente tarifrio.<br/>
	 * 
	 * Frmula: (KM * Coeficiente Tarifrio)
	 * 
	 * Se o parametro ruta no for informado, ser gerado tarifas para todas as
	 * rutas. <br/>
	 * 
	 * Obs.: Essa opero apenas gera tarifas que ainda no esto geradas<br/>
	 * 
	 * @param rutaId
	 * @return A quantidade de registros afetadas
	 */
	public Integer gerarTarifaPorCoeficiente(Integer rutaId);

	/**
	 * Atualiza as tarifas de acordo o clculo do coeficiente tarifrio.<br/>
	 * 
	 * Frmula: (KM * Coeficiente Tarifrio)
	 * 
	 * Se o parametro ruta no for informado, ser atualizado as tarifas para
	 * todas as rutas.<br/>
	 * 
	 * @param rutaId
	 * @return TODO
	 */
	public Integer atualizarTarifaPorCoeficiente(Integer rutaId);
	
	/**
	 * Gera as novas tarifas e atualiza as j existentes
	 * 
	 * Utiliza os mtodos {@link #gerarTarifaPorCoeficiente(Integer)} e {@link #atualizarTarifaPorCoeficiente(Integer)}
	 * 
	 * @param rudaId
	 * @param orgaoConcedenteId 
	 * @return - Retorna o total de registros inseridos + atualizados
	 */
	public Integer gerarAtualizarTarifaPorCoeficiente(Integer rudaId, Integer orgaoConcedenteId);
	
	/**
	 * Copia a tarifa oficial para a tabela de tarifa de acordo com a vigencia especificada
	 * @param vigenciaTarifa
	 */
	public void copiarParaTarifa(VigenciaTarifa vigenciaTarifa);

}
